package gui;

import java.awt.Graphics;
import java.awt.Color;

public class Graph {
	private final Graphics g;
	private final int dx;
	private final int dy;
	private final int w;
	private final int h;
	private int maxValue;
	
	/**
	 * 
	 * @param context The context on which the graph will be plotted
	 */
	public Graph(Graphics context)
	{
		this(context, 0, 0, 200, 200, -1);
	}
	/**
	 * A full detail constructor for the Graph object 
	 * @param context The graphics context on which the graph is going to be plotted
	 * @param xOffset The coordinates of the top left corner of the graph
	 * @param yOffset The coordinates of the top left corner of the graph
	 * @param width The width of the graph area
	 * @param height The height of the graph area
	 * @param maxVl The greatest value viewable on the graph, -1 if the
	 * greatest viewable value corresponds to the maximum value in the input arrays 
	 */
	public Graph(Graphics context, int xOffset, int yOffset, int width, int height, int maxVl)
	{
		g = context;
		dx = xOffset;
		dy = yOffset;
		w = width;
		h = height;
		maxValue = maxVl;
	}
	
	/**
	 * A function for plotting data from two arrays on our graph
	 * @param first The first array of data
	 * @param second The second array of data
	 */
	public void plotGraphs(int first[], int second[])
	{
		int n = (first == null) ? 0 : first.length;
		int m = (second == null) ? 0 : second.length;
		Color c = g.getColor();
		if (maxValue == -1)
		{
			for (int i = 0; i < n; i++)
				maxValue = Math.max(first[i], maxValue);
			for (int i = 0; i < m; i++)
				maxValue = Math.max(second[i], maxValue);
		}
		double unitX = w / (double)Math.max(n, m);
		double unitY = ((double)h) / maxValue; 
		if (n != 0)
		{
			g.setColor(Color.GREEN);
			for (int i = 0; i < n - 1; i++)
				g.drawLine((int)(i * unitX + dx), h - (int)(first[i] * unitY) + dy
						, (int)((i+1) * unitX + dx), h - (int)(first[i+1] * unitY) + dy);
		}
		if (m != 0)
		{
			g.setColor(Color.RED);
			for (int i = 0; i < m - 1; i++)
				g.drawLine((int)(i * unitX + dx), h - (int)(second[i] * unitY) + dy,
						(int)((i+1) * unitX + dx), h - (int)(second[i+1] * unitY) + dy);
		}		
		g.setColor(c);			
	}
}
